# $File: //depot/OurNet-BBS/BBS/MELIX/Group.pm $ $Author: autrijus $
# $Revision: #4 $ $Change: 1270 $ $DateTime: 2001/06/24 07:15:18 $

package OurNet::BBS::MELIX::Group;

use base qw/OurNet::BBS::MAPLE3::Group/;
use fields qw/_cache/;

BEGIN {__PACKAGE__->initvars() }

1;
